<?php

namespace Drupal\domain_lang\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\domain_lang\DomainLangHandlerInterface;
use Drupal\domain\DomainNegotiatorInterface;
use Drupal\language\Form\NegotiationBrowserDeleteForm;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a confirmation form for deleting a browser language negotiation mapping.
 */
class DomainLangNegotiationBrowserDeleteForm extends NegotiationBrowserDeleteForm {

  /**
   * The domain lang handler.
   *
   * @var \Drupal\domain_lang\DomainLangHandlerInterface
   */
  protected $domainLangHandler;

  /**
   * The domain negotiator.
   *
   * @var \Drupal\domain\DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\domain_lang\DomainLangHandlerInterface $domain_lang_handler
   *   The domain lang handler.
   * @param \Drupal\domain\DomainNegotiatorInterface $domain_negotiator
   *   The domain negotiator service.
   */
  public function __construct(DomainLangHandlerInterface $domain_lang_handler, DomainNegotiatorInterface $domain_negotiator) {
    $this->domainLangHandler = $domain_lang_handler;
    $this->domainNegotiator = $domain_negotiator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('domain_lang.handler'),
      $container->get('domain.negotiator')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url(
      'domain_lang.negotiation_browser',
      ['domain' => $this->domainNegotiator->getActiveId()]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->domainLangHandler->removeConfigItem(
      'language.mappings',
      'map.' . $this->browserLangcode
    );

    $args = ['%browser' => $this->browserLangcode];
    $this->logger('language')->notice('The browser language detection mapping for the %browser browser language code has been deleted.', $args);

    $form_state->setRedirect(
      'domain_lang.negotiation_browser',
      ['domain' => $this->domainNegotiator->getActiveId()]
    );
    drupal_set_message($this->t('The mapping for the %browser browser language code has been deleted.', $args));
  }

}
