<?php

namespace Drupal\domain_lang\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\domain_lang\DomainLangHandlerInterface;
use Drupal\language\Form\NegotiationUrlForm;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure the URL language negotiation method for this site.
 */
class DomainLangNegotiationUrlForm extends NegotiationUrlForm {

  /**
   * The domain lang handler.
   *
   * @var \Drupal\domain_lang\DomainLangHandlerInterface
   */
  protected $domainLangHandler;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\domain_lang\DomainLangHandlerInterface $domain_lang_handler
   *   The domain lang handler.
   */
  public function __construct(ConfigFactoryInterface $config_factory, LanguageManagerInterface $language_manager, DomainLangHandlerInterface $domain_lang_handler) {
    parent::__construct($config_factory, $language_manager);
    $this->domainLangHandler = $domain_lang_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('language_manager'),
      $container->get('domain_lang.handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->domainLangHandler->updateConfigItems(
      'language.negotiation',
      [
        'url.source' => $form_state->getValue('language_negotiation_url_part'),
        'url.prefixes' => $form_state->getValue('prefix'),
        'url.domains' => $form_state->getValue('domain'),
      ]
    );

    $form_state->disableRedirect();
    drupal_set_message($this->t('The configuration options have been saved.'));
  }

}
